@@ -22,7 +22,7 @@
 #endif
 
 #ifndef LIBCPP_HOCON_DEPRECATED
-#  define LIBCPP_HOCON_DEPRECATED 
+#  define LIBCPP_HOCON_DEPRECATED __attribute__ ((__deprecated__))
 #endif
 
 #ifndef LIBCPP_HOCON_DEPRECATED_EXPORT
@@ -39,4 +39,4 @@
 #  endif
 #endif
 
-#endif
+#endif /* LIBCPP_HOCON_EXPORT_H */
